==> smuxi_0.6.2.orig.tar.gz: smuxi-0.6.2/src/Frontend-GNOME/SplashScreenWindow.cs <==
/*
 * $Id: SplashScreenWindow.cs 183 2007-04-21 15:14:23Z meebey $
 * $URL: svn+ssh://svn.qnetp.net/svn/smuxi/smuxi/trunk/src/Frontend-GNOME/SplashScreenWindow.cs $
 * $Rev: 183 $
 * $Author: meebey $
 * $Date: 2007-04-21 17:14:23 +0200 (Sat, 21 Apr 2007) $
 *
 * smuxi - Smart MUltipleXed Irc
 *
 * Copyright (c) 2005-2006 Mirco Bauer <meebey@meebey.net>
 *
 * Full GPL License: <http://www.gnu.org/licenses/gpl.txt>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 */

using System;

namespace Smuxi.Frontend.Gnome
{
    public class SplashScreenWindow : Gtk.Window
    {
        public SplashScreenWindow() : base("smuxi - Splashscreen")
        {
            Decorated = false;
            WindowPosition = Gtk.WindowPosition.Center;
            Add(new Gtk.Image(new Gdk.Pixbuf(null, "splashscreen.png")));
            ShowAll();
            
            // force GTK+ to draw us, regardless if we are in the glib/gtk main-loop
            while (Gtk.Application.EventsPending()) {
                Gtk.Application.RunIteration();
            }
        }
    }
}

==> smuxi_1.0.7.orig.tar.gz: smuxi-1.0.7/src/Frontend-GNOME/SplashScreenWindow.cs <==
/*
 * $Id$
 * $URL$
 * $Rev$
 * $Author$
 * $Date$
 *
 * Smuxi - Smart MUltipleXed Irc
 *
 * Copyright (c) 2005-2006 Mirco Bauer <meebey@meebey.net>
 *
 * Full GPL License: <http://www.gnu.org/licenses/gpl.txt>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 */

using System;

namespace Smuxi.Frontend.Gnome
{
    public class SplashScreenWindow : Gtk.Window
    {
        public SplashScreenWindow() : base("Smuxi - Splashscreen")
        {
            Decorated = false;
            WindowPosition = Gtk.WindowPosition.Center;
            Add(new Gtk.Image(new Gdk.Pixbuf(null, "splashscreen.png")));
            ShowAll();
            
            // force GTK+ to draw us, regardless if we are in the glib/gtk main-loop
            while (Gtk.Application.EventsPending()) {
                Gtk.Application.RunIteration();
            }
        }
    }
}
